@@ -1,14 +1,12 @@
 from esphome.components import binary_sensor
 import esphome.config_validation as cv
 import esphome.codegen as cg
-from esphome.const import CONF_ID
+from esphome.const import CONF_ID, CONF_SENSOR_DATAPOINT
 from .. import tuya_ns, CONF_TUYA_ID, Tuya
 
 DEPENDENCIES = ["tuya"]
 CODEOWNERS = ["@jesserockz"]
 
-CONF_SENSOR_DATAPOINT = "sensor_datapoint"
-
 TuyaBinarySensor = tuya_ns.class_(
     "TuyaBinarySensor", binary_sensor.BinarySensor, cg.Component
 )
